@@ -7,7 +7,7 @@ package App::Pods2Site::Args;
 use strict;
 use warnings;
 
-our $VERSION = '1.001';
+our $VERSION = '1.002';
 my $version = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -313,7 +313,7 @@ sub __parseArgv
 		$self->{css} = $css;
 	}
 
-	$rawOpts{title} = $rawOpts{title} || ($Config{myuname} ? "Pods2Site : $Config{myuname}" : 'Pods2Site');
+	$rawOpts{title} = $rawOpts{title} || ($Config{myuname} ? $Config{myuname} : 'Pods2Site');
 	$self->{title} = $rawOpts{title};
 	
 	$self->{style} = $rawOpts{style};
